@@ -12,7 +12,7 @@
 #See the License for the specific language governing permissions and
 #limitations under the License.
 #
-"""library for parsing and printing role, cookbook and node information"""
+"""Library for parsing and printing role, cookbook and node information"""
 import os
 import json
 import subprocess
@@ -29,15 +29,25 @@ from littlechef.exceptions import FileNotFoundError
 knife_installed = True
 
 
-def resolve_hostname(name):
+def _resolve_hostname(name):
     """Returns resolved hostname using the ssh config"""
-    if not os.path.exists(os.path.join("nodes", name + ".json")):
+    if env.ssh_config is None:
+        return name
+    elif not os.path.exists(os.path.join("nodes", name + ".json")):
         resolved_name = env.ssh_config.lookup(name)['hostname']
         if os.path.exists(os.path.join("nodes", resolved_name + ".json")):
             name = resolved_name
     return name
 
 
+def get_env_host_string():
+    if not env.host_string:
+        abort('no node specified\nUsage: fix node:<MYNODES> <COMMAND>')
+    if '@' in env.host_string:
+        env.user = env.host_string.split('@')[0]
+    return _resolve_hostname(env.host_string)
+
+
 def env_from_template(name):
     """Returns a basic environment structure"""
     return {
@@ -138,6 +148,30 @@ def get_nodes_with_role(role_name, environment=None):
                 yield n
 
 
+def get_nodes_with_tag(tag, environment=None, include_guests=False):
+    """Get all nodes which include a given tag"""
+    nodes = get_nodes(environment)
+    nodes_mapping = dict((n['name'], n) for n in nodes)
+    for n in nodes:
+        if tag in n.get('tags', []):
+            # Remove from node mapping so it doesn't get added twice by
+            # guest walking below
+            try:
+                del nodes_mapping[n['fqdn']]
+            except KeyError:
+                pass
+            yield n
+            # Walk guest if it is a host
+            if include_guests and n.get('virtualization', {}).get('role') == 'host':
+                for guest in n['virtualization']['guests']:
+                    try:
+                        yield nodes_mapping[guest['fqdn']]
+                    except KeyError:
+                        # we ignore guests which are not in the same
+                        # chef environments than their hosts for now
+                        pass
+
+
 def get_nodes_with_recipe(recipe_name, environment=None):
     """Get all nodes which include a given recipe,
     prefix-searches are also supported
